@@ -1,7 +1,7 @@
 /*
  * This file is part of OpenModelica.
  *
- * Copyright (c) 1998-2014, Open Source Modelica Consortium (OSMC),
+ * Copyright (c) 1998-CurrentYear, Open Source Modelica Consortium (OSMC),
  * c/o Linköpings universitet, Department of Computer and Information Science,
  * SE-58183 Linköping, Sweden.
  *
@@ -31,7 +31,47 @@
 #if !defined(OMC_NO_STATESELECTION)
 
 #include "stateset.h"
-#include "util/omc_error.h"
+#include "../../util/omc_error.h"
+
+/*! \fn printStateSelectionInfo
+ *
+ *  function prints actually information about current state selection
+ *
+ *  \param [in]  [data]
+ *  \param [in]  [set]
+ *
+ *  \author wbraun
+ */
+void printStateSelectionInfo(DATA *data, STATE_SET_DATA *set)
+{
+  long k, l;
+
+  infoStreamPrint(LOG_DSS, 0, "Select %ld state%s from %ld candidates.", set->nStates, set->nStates == 1 ? "" : "s", set->nCandidates);
+  infoStreamPrint(LOG_DSS, 1, "State candidates:");
+  for(k=0; k < set->nCandidates; k++)
+  {
+    infoStreamPrint(LOG_DSS, 0, "[%ld] %s", k+1, set->statescandidates[k]->name);
+  }
+  messageClose(LOG_DSS);
+
+  infoStreamPrint(LOG_DSS, 1, "Selected state%s", set->nStates == 1 ? "" : "s");
+  {
+    unsigned int aid = set->A->id - data->modelData->integerVarsData[0].info.id;
+    modelica_integer *Adump = &(data->localData[0]->integerVars[aid]);
+    for(k=0; k < set->nStates; k++)
+    {
+      for(l=0; l < set->nCandidates; l++)
+      {
+        if (Adump[k*set->nCandidates+l] == 1)
+        {
+          infoStreamPrint(LOG_DSS, 0, "[%ld] %s", l+1, set->statescandidates[l]->name);
+          break;
+        }
+      }
+    }
+  }
+  messageClose(LOG_DSS);
+}
 
 /*! \fn initializeStateSetJacobians
  *
@@ -46,12 +86,17 @@ void initializeStateSetJacobians(DATA *data, threadData_t *threadData)
   TRACE_PUSH
   long i = 0;
   STATE_SET_DATA *set = NULL;
+  unsigned int jacIndex;
+  ANALYTIC_JACOBIAN* jacobian;
 
   /* go troug all state sets*/
   for(i=0; i<data->modelData->nStateSets; i++)
   {
     set = &(data->simulationInfo->stateSetData[i]);
-    if(set->initialAnalyticalJacobian(data, threadData))
+    jacIndex = set->jacobianIndex;
+    jacobian = &(data->simulationInfo->analyticJacobians[jacIndex]);
+
+    if(set->initialAnalyticalJacobian(data, threadData, jacobian))
     {
       throwStreamPrint(threadData, "can not initialze Jacobians for dynamic state selection");
     }
@@ -139,64 +184,70 @@ static void getAnalyticalJacobianSet(DATA* data, threadData_t *threadData, unsig
   TRACE_PUSH
   unsigned int i, j, k, l, ii;
   unsigned int jacIndex = data->simulationInfo->stateSetData[index].jacobianIndex;
-  unsigned int nrows = data->simulationInfo->analyticJacobians[jacIndex].sizeRows;
-  unsigned int ncols = data->simulationInfo->analyticJacobians[jacIndex].sizeCols;
+  ANALYTIC_JACOBIAN* jacobian = &(data->simulationInfo->analyticJacobians[jacIndex]);
+
+  unsigned int nrows = jacobian->sizeRows;
+  unsigned int ncols = jacobian->sizeCols;
   double* jac = data->simulationInfo->stateSetData[index].J;
 
+
   /* set all elements to zero */
   memset(jac, 0, (nrows*ncols*sizeof(double)));
 
-  for(i=0; i < data->simulationInfo->analyticJacobians[jacIndex].sparsePattern.maxColors; i++)
+  if (jacobian->constantEqns != NULL) {
+    jacobian->constantEqns(data, threadData, jacobian, NULL);
+  }
+  for(i=0; i < jacobian->sparsePattern->maxColors; i++)
   {
-    for(ii=0; ii < data->simulationInfo->analyticJacobians[jacIndex].sizeCols; ii++)
-      if(data->simulationInfo->analyticJacobians[jacIndex].sparsePattern.colorCols[ii]-1 == i)
-        data->simulationInfo->analyticJacobians[jacIndex].seedVars[ii] = 1;
+    for(ii=0; ii < jacobian->sizeCols; ii++)
+      if(jacobian->sparsePattern->colorCols[ii]-1 == i)
+        jacobian->seedVars[ii] = 1;
 
 /*
     if(ACTIVE_STREAM(LOG_DSS_JAC))
     {
       infoStreamPrint(LOG_DSS_JAC, 1, "Caluculate one col:");
-      for(l=0; l < data->simulationInfo->analyticJacobians[jacIndex].sizeCols; l++)
-        infoStreamPrint(LOG_DSS_JAC, 0, "seed: data->simulationInfo->analyticJacobians[index].seedVars[%d]= %f", l, data->simulationInfo->analyticJacobians[jacIndex].seedVars[l]);
+      for(l=0; l < jacobian->sizeCols; l++)
+        infoStreamPrint(LOG_DSS_JAC, 0, "seed: data->simulationInfo->analyticJacobians[index].seedVars[%d]= %f", l, jacobian->seedVars[l]);
       messageClose(LOG_DSS_JAC);
     }
 */
-    (data->simulationInfo->stateSetData[index].analyticalJacobianColumn)(data, threadData);
+    (data->simulationInfo->stateSetData[index].analyticalJacobianColumn)(data, threadData, jacobian, NULL);
 
-    for(j=0; j < data->simulationInfo->analyticJacobians[jacIndex].sizeCols; j++)
+    for(j=0; j < jacobian->sizeCols; j++)
     {
-      if(data->simulationInfo->analyticJacobians[jacIndex].seedVars[j] == 1)
+      if(jacobian->seedVars[j] == 1)
       {
-        ii = data->simulationInfo->analyticJacobians[jacIndex].sparsePattern.leadindex[j];
+        ii = jacobian->sparsePattern->leadindex[j];
 
         /* infoStreamPrint(LOG_DSS_JAC, 0, "take for %d -> %d\n", j, ii); */
 
-        while(ii < data->simulationInfo->analyticJacobians[jacIndex].sparsePattern.leadindex[j+1])
+        while(ii < jacobian->sparsePattern->leadindex[j+1])
         {
-          l  = data->simulationInfo->analyticJacobians[jacIndex].sparsePattern.index[ii];
-          k  = j*data->simulationInfo->analyticJacobians[jacIndex].sizeRows + l;
-          jac[k] = data->simulationInfo->analyticJacobians[jacIndex].resultVars[l];
-          /* infoStreamPrint(LOG_DSS_JAC, 0, "write %d. in jac[%d]-[%d, %d]=%f from col[%d]=%f", ii, k, l, j, jac[k], l, data->simulationInfo->analyticJacobians[jacIndex].resultVars[l]); */
+          l  = jacobian->sparsePattern->index[ii];
+          k  = j*jacobian->sizeRows + l;
+          jac[k] = jacobian->resultVars[l];
+          /* infoStreamPrint(LOG_DSS_JAC, 0, "write %d. in jac[%d]-[%d, %d]=%f from col[%d]=%f", ii, k, l, j, jac[k], l, jacobian->resultVars[l]); */
           ii++;
         };
       }
     }
-    for(ii=0; ii < data->simulationInfo->analyticJacobians[jacIndex].sizeCols; ii++)
-      if(data->simulationInfo->analyticJacobians[jacIndex].sparsePattern.colorCols[ii]-1 == i)
-        data->simulationInfo->analyticJacobians[jacIndex].seedVars[ii] = 0;
+    for(ii=0; ii < jacobian->sizeCols; ii++)
+      if(jacobian->sparsePattern->colorCols[ii]-1 == i)
+        jacobian->seedVars[ii] = 0;
   }
 
   if(ACTIVE_STREAM(LOG_DSS_JAC))
   {
-    char *buffer = (char*)malloc(sizeof(char)*data->simulationInfo->analyticJacobians[jacIndex].sizeCols*20);
+    char *buffer = (char*)malloc(sizeof(char)*jacobian->sizeCols*20);
 
-    infoStreamPrint(LOG_DSS_JAC, 1, "jacobian %dx%d [id: %d]", data->simulationInfo->analyticJacobians[jacIndex].sizeRows, data->simulationInfo->analyticJacobians[jacIndex].sizeCols, jacIndex);
+    infoStreamPrint(LOG_DSS_JAC, 1, "jacobian %dx%d [id: %d]", jacobian->sizeRows, jacobian->sizeCols, jacIndex);
 
-    for(i=0; i<data->simulationInfo->analyticJacobians[jacIndex].sizeRows; i++)
+    for(i=0; i<jacobian->sizeRows; i++)
     {
       buffer[0] = 0;
-      for(j=0; j < data->simulationInfo->analyticJacobians[jacIndex].sizeCols; j++)
-        sprintf(buffer, "%s%.5e ", buffer, jac[i*data->simulationInfo->analyticJacobians[jacIndex].sizeCols+j]);
+      for(j=0; j < jacobian->sizeCols; j++)
+        sprintf(buffer, "%s%.5e ", buffer, jac[i*jacobian->sizeCols+j]);
       infoStreamPrint(LOG_DSS_JAC, 0, "%s", buffer);
     }
     messageClose(LOG_DSS_JAC);
@@ -236,7 +287,6 @@ static void setAMatrix(modelica_integer* newEnable, modelica_integer nCandidates
       unsigned int firstrealid = data->modelData->realVarsData[0].info.id;
       unsigned int id = statecandidates[col]->id-firstrealid;
       unsigned int sid = states[row]->id-firstrealid;
-      infoStreamPrint(LOG_DSS, 0, "select %s", statecandidates[col]->name);
       /* set A[row, col] */
       A[row*nCandidates + col] = 1;
       /* reinit state */
@@ -252,21 +302,24 @@ static void setAMatrix(modelica_integer* newEnable, modelica_integer nCandidates
  *  ??? desc ???
  *
  *  \param [ref] [oldPivot]
- *  \param [ref] [newPivot]
- *  \param [ref] [nCandidates]
- *  \param [ref] [nDummyStates]
- *  \param [ref] [nStates]
- *  \param [ref] [A]
- *  \param [ref] [states]
- *  \param [ref] [statecandidates]
+ *  \param [ref] [set]
+ *  \param [ref] [setIndex]
  *  \param [ref] [data]
+ *  \param [ref] [switchStates]
  *  \return ???
  */
-static int comparePivot(modelica_integer *oldPivot, modelica_integer *newPivot, modelica_integer nCandidates, modelica_integer nDummyStates, modelica_integer nStates, VAR_INFO* A, VAR_INFO** states, VAR_INFO** statecandidates, DATA *data, int switchStates)
+static int comparePivot(modelica_integer *oldPivot, STATE_SET_DATA *set, long setIndex, DATA *data, int switchStates)
 {
   TRACE_PUSH
   modelica_integer i;
   int ret = 0;
+  modelica_integer *newPivot = set->colPivot;
+  modelica_integer nCandidates = set->nCandidates;
+  modelica_integer nDummyStates = set->nDummyStates;
+  modelica_integer nStates = set->nStates;
+  VAR_INFO* A = set->A;
+  VAR_INFO** states = set->states;
+  VAR_INFO** statecandidates = set->statescandidates;
   modelica_integer* oldEnable = (modelica_integer*) calloc(nCandidates, sizeof(modelica_integer));
   modelica_integer* newEnable = (modelica_integer*) calloc(nCandidates, sizeof(modelica_integer));
 
@@ -283,9 +336,13 @@ static int comparePivot(modelica_integer *oldPivot, modelica_integer *newPivot,
     {
       if(switchStates)
       {
-        infoStreamPrint(LOG_DSS, 1, "select new states at time %f", data->localData[0]->timeValue);
         setAMatrix(newEnable, nCandidates, nStates, A, states, statecandidates, data);
-        messageClose(LOG_DSS);
+        /* debug */
+        if(ACTIVE_STREAM(LOG_DSS)){
+          infoStreamPrint(LOG_DSS, 1, "StateSelection Set %ld at time = %f", setIndex, data->localData[0]->timeValue);
+          printStateSelectionInfo(data, set);
+          messageClose(LOG_DSS);
+        }
       }
       ret = -1;
       break;
@@ -299,81 +356,33 @@ static int comparePivot(modelica_integer *oldPivot, modelica_integer *newPivot,
   return ret;
 }
 
-/*! \fn printStateSelectionInfo
+/*! \fn stateSelectionSet
  *
- *  function prints actually information about current state selection
- *
- *  \param [in]  [data]
- *  \param [in]  [set]
- *
- *  \author wbraun
- */
-void printStateSelectionInfo(DATA *data, STATE_SET_DATA *set)
-{
-  long k, l;
-
-  infoStreamPrint(LOG_DSS, 1, "Select %ld states from %ld candidates.", set->nStates, set->nCandidates);
-  for(k=0; k < set->nCandidates; k++)
-  {
-    infoStreamPrint(LOG_DSS, 0, "[%ld] cadidate %s", k+1, set->statescandidates[k]->name);
-  }
-  messageClose(LOG_DSS);
-
-  infoStreamPrint(LOG_DSS, 1, "Selected states");
-  {
-    unsigned int aid = set->A->id - data->modelData->integerVarsData[0].info.id;
-    modelica_integer *Adump = &(data->localData[0]->integerVars[aid]);
-    for(k=0; k < set->nStates; k++)
-    {
-      for(l=0; l < set->nCandidates; l++)
-      {
-        if (Adump[k*set->nCandidates+l] == 1)
-        {
-          infoStreamPrint(LOG_DSS, 0, "[%ld] %s", k+1, set->statescandidates[k]->name);
-        }
-      }
-    }
-  }
-  messageClose(LOG_DSS);
-}
-
-/*! \fn stateSelection
- *
- *  function to select the actual states
+ *  function to select the actual states for an individual stateSet
  *
  *  \param [ref] [data]
+ *  \param [ref] [threadData]
  *  \param [in]  [reportError]
  *  \param [in]  [switchStates] flag for switch states, function does switch only if this switchStates = 1
- *  \return ???
+ *  \param [in]  [setIndex] unique index of the stateSet
+ *  \param [in]  [globalres] flag for discontinuous timestep in the case of a state switch for all sets before
+ *  \return      [globalres] flag for discontinuous timestep in the case of a state switch for at least one set
  *
- *  \author Frenkel TUD
+ *  \author Abdelhak / Frenkel TUD
  */
-int stateSelection(DATA *data, threadData_t *threadData, char reportError, int switchStates)
+int stateSelectionSet(DATA *data, threadData_t *threadData, char reportError, int switchStates, long setIndex, int globalres)
 {
-  TRACE_PUSH
-  long i=0;
-  long j=0;
-  int globalres=0;
-  long k=0;
-  long l=0;
-
-  /* go through all the state sets */
-  for(i=0; i<data->modelData->nStateSets; i++)
-  {
+    long j=0;
+    long k=0;
+    long l=0;
+    long m=0;
     int res=0;
-    STATE_SET_DATA *set = &(data->simulationInfo->stateSetData[i]);
+    STATE_SET_DATA *set = &(data->simulationInfo->stateSetData[setIndex]);
     modelica_integer* oldColPivot = (modelica_integer*) malloc(set->nCandidates * sizeof(modelica_integer));
     modelica_integer* oldRowPivot = (modelica_integer*) malloc(set->nDummyStates * sizeof(modelica_integer));
 
-    /* debug */
-    if(ACTIVE_STREAM(LOG_DSS))
-    {
-      infoStreamPrint(LOG_DSS, 1, "StateSelection Set %ld at time = %f", i, data->localData[0]->timeValue);
-      printStateSelectionInfo(data, set);
-      messageClose(LOG_DSS);
-    }
     /* generate jacobian, stored in set->J */
-    getAnalyticalJacobianSet(data, threadData, i);
+    getAnalyticalJacobianSet(data, threadData, setIndex);
 
     /* call pivoting function to select the states */
     memcpy(oldColPivot, set->colPivot, set->nCandidates*sizeof(modelica_integer));
@@ -381,27 +390,29 @@ int stateSelection(DATA *data, threadData_t *threadData, char reportError, int s
     if((pivot(set->J, set->nDummyStates, set->nCandidates, set->rowPivot, set->colPivot) != 0) && reportError)
     {
       /* error, report the matrix and the time */
-      char *buffer = (char*)malloc(sizeof(char)*data->simulationInfo->analyticJacobians[set->jacobianIndex].sizeCols*10);
 
+      char *buffer = (char*)malloc(sizeof(char)*data->simulationInfo->analyticJacobians[set->jacobianIndex].sizeCols*100+5);
       warningStreamPrint(LOG_DSS, 1, "jacobian %dx%d [id: %ld]", data->simulationInfo->analyticJacobians[set->jacobianIndex].sizeRows, data->simulationInfo->analyticJacobians[set->jacobianIndex].sizeCols, set->jacobianIndex);
-      for(i=0; i < data->simulationInfo->analyticJacobians[set->jacobianIndex].sizeRows; i++)
+
+      for(m=0; m < data->simulationInfo->analyticJacobians[set->jacobianIndex].sizeRows; m++)
       {
         buffer[0] = 0;
         for(j=0; j < data->simulationInfo->analyticJacobians[set->jacobianIndex].sizeCols; j++)
-          sprintf(buffer, "%s%.5e ", buffer, set->J[i*data->simulationInfo->analyticJacobians[set->jacobianIndex].sizeCols+j]);
+          sprintf(buffer, "%s%.5e ", buffer, set->J[m*data->simulationInfo->analyticJacobians[set->jacobianIndex].sizeCols+j]);
         warningStreamPrint(LOG_DSS, 0, "%s", buffer);
       }
+
       free(buffer);
 
-      for(i=0; i<set->nCandidates; i++)
-        warningStreamPrint(LOG_DSS, 0, "%s", set->statescandidates[i]->name);
+      for(m=0; m<set->nCandidates; m++)
+        warningStreamPrint(LOG_DSS, 0, "%s", set->statescandidates[m]->name);
       messageClose(LOG_DSS);
 
       throwStreamPrint(threadData, "Error, singular Jacobian for dynamic state selection at time %f\nUse -lv LOG_DSS_JAC to get the Jacobian", data->localData[0]->timeValue);
     }
     /* if we have a new set throw event for reinitialization
        and set the A matrix for set.x=A*(states) */
-    res = comparePivot(oldColPivot, set->colPivot, set->nCandidates, set->nDummyStates, set->nStates, set->A, set->states, set->statescandidates, data, switchStates);
+    res = comparePivot(oldColPivot, set, setIndex, data, switchStates);
     if(!switchStates)
     {
       memcpy(set->colPivot, oldColPivot, set->nCandidates*sizeof(modelica_integer));
@@ -412,6 +423,31 @@ int stateSelection(DATA *data, threadData_t *threadData, char reportError, int s
 
     free(oldColPivot);
     free(oldRowPivot);
+    return globalres;
+}
+
+/*! \fn stateSelection
+ *
+ *  function to select the actual states
+ *
+ *  \param [ref] [data]
+ *  \param [ref] [threadData]
+ *  \param [in]  [reportError]
+ *  \param [in]  [switchStates] flag for switch states, function does switch only if this switchStates = 1
+ *  \return      [globalres] flag for discontinuous timestep in the case of a state switch for at least one set
+ *
+ *  \author Frenkel TUD
+ */
+int stateSelection(DATA *data, threadData_t *threadData, char reportError, int switchStates)
+{
+  TRACE_PUSH
+  long i=0;
+  int globalres=0;
+
+  /* go through all the state sets */
+  for(i=0; i<data->modelData->nStateSets; i++)
+  {
+    globalres = stateSelectionSet(data, threadData, reportError, switchStates, i, globalres);
   }
 
   TRACE_POP
