@@ -1154,79 +1154,88 @@ QString StringHandler::escapeTextAnnotationString(QString value)
   return res;
 }
 
-#define CONSUME_CHAR(value,res,i) \
-  if (value.at(i) == '\\') { \
-  i++; \
-  switch (value[i].toAscii()) { \
-  case '\'': res.append('\''); break; \
-  case '"':  res.append('\"'); break; \
-  case '?':  res.append('\?'); break; \
-  case '\\': res.append('\\'); break; \
-  case 'a':  res.append('\a'); break; \
-  case 'b':  res.append('\b'); break; \
-  case 'f':  res.append('\f'); break; \
-  case 'n':  res.append('\n'); break; \
-  case 'r':  res.append('\r'); break; \
-  case 't':  res.append('\t'); break; \
-  case 'v':  res.append('\v'); break; \
-  } \
+#define CONSUME_CHAR(value, res, len, i) \
+  if (value[i] == '\\' && i + 1 < len) { \
+    i++; \
+    switch (value[i].toAscii()) { \
+      case '\'': res.append('\''); break; \
+      case '"':  res.append('\"'); break; \
+      case '?':  res.append('\?'); break; \
+      case '\\': res.append('\\'); break; \
+      case 'a':  res.append('\a'); break; \
+      case 'b':  res.append('\b'); break; \
+      case 'f':  res.append('\f'); break; \
+      case 'n':  res.append('\n'); break; \
+      case 'r':  res.append('\r'); break; \
+      case 't':  res.append('\t'); break; \
+      case 'v':  res.append('\v'); break; \
+      default:   res.append('\\') \
+                    .append(value[i]); \
+    } \
   } else { \
-  res.append(value[i]); \
+    res.append(value[i]); \
   }
 
 QString StringHandler::unparse(QString value)
 {
   QString res;
   value = value.trimmed();
-  if (value.length() > 1 && value.at(0) == '\"' && value.at(value.length() - 1) == '\"') {
-    value = value.mid(1, (value.length() - 2));
-    for (int i=0; i < value.length(); i++) {
-      CONSUME_CHAR(value,res,i);
+  int len = value.length();
+  if (len > 2 && value.at(0) == '\"' && value.at(len - 1) == '\"') {
+    len -= 2;
+    value = value.mid(1, len);
+    for (int i = 0; i < len; i++) {
+      CONSUME_CHAR(value, res, len, i);
     }
-    return res;
-  } else {
-    return "";
   }
+  return res;
 }
 
 QStringList StringHandler::unparseStrings(QString value)
 {
   QStringList lst;
-  value = value.trimmed();
-  if (value[0] != '{') return lst; // ERROR?
-  int i=1;
   QString res;
-  while (value[i] == '"') {
+  value = value.trimmed();
+  int len = value.length();
+  if (len < 2 || value[0] != '{') {
+    return lst; // ERROR?
+  }
+  if (value[1] == '}') {
+    return lst; // empty list
+  }
+  int i = 1;
+  while (i < len && value[i] == '"') {
     i++;
-    while (value.at(i) != '"') {
-      CONSUME_CHAR(value,res,i);
-      i++;
+    while ((i < len && value[i] != '"')
       /* if we have unexpected double quotes then, however omc should return \" */
-      /* remove this block once fixed in omc */
-      if (value[i] == '"' && value[i+1] != ',') {
-        if (value[i+1] != '}') {
-          CONSUME_CHAR(value,res,i);
-          i++;
-        }
-      }
-      /* remove this block once fixed in omc */
+      /* remove this condition once fixed in omc */
+      || (i + 1 < len && value[i + 1] != ',' && value[i + 1] != '}')
+      /* remove this condition once fixed in omc */
+    ) {
+      CONSUME_CHAR(value, res, len, i);
+      i++;
     }
-    i++;
-    if (value[i] == '}') {
+    if (i < len) {
       lst.append(res);
+      res = QString();
+      i++;
+    }
+    if (i == len) {
+      return lst; // ERROR?
+    }
+    if (value[i] == '}') {
       return lst;
     }
     if (value[i] == ',') {
-      lst.append(res);
       i++;
-      res = "";
-      while (value[i] == ' ')     // if we have space before next value e.g {"x", "y", "z"}
+      while (i < len && value[i] == ' ') { // if we have space before next value e.g {"x", "y", "z"}
         i++;
-      continue;
-    }
-    while (value[i] != '"' && !value[i].isNull()) {
-      i++;
-      fprintf(stderr, "error? malformed string-list. skipping: %c\n", value[i].toAscii());
+      }
+    } else {
+      while (i < len && value[i] != '"') {
+        fprintf(stderr, "error? malformed string-list. skipping: %c\n", value[i].toAscii());
+        i++;
+      }
     }
   }
   return lst; // ERROR?
@@ -1596,7 +1605,7 @@ QStringList StringHandler::makeVariablePartsWithInd(QString variable)
 
   if (!varParts.isEmpty()) {
 	  QString* lastStr = &(varParts.last());
-	  int i = lastStr->lastIndexOf(QRegExp("\\[\\d+\\]"));
+	  int i = lastStr->lastIndexOf(QRegularExpression("\\[\\d+\\]"));
 	  if(i>=0){
 		  QString indexPart = *lastStr;
 		  indexPart.remove(0,i);
@@ -1668,6 +1677,41 @@ QProcessEnvironment StringHandler::simulationProcessEnvironment()
   environment.insert("PATH", OMHOMEBin + ";" + environment.value("PATH"));
   return environment;
 }
+
+/*!
+ * \brief StringHandler::modelicaSimulationProcessEnvironment
+ * Returns the environment for simulation process.
+ * \param pathsFileName
+ * \param errorMsg
+ * \return
+ */
+QProcessEnvironment StringHandler::modelicaSimulationProcessEnvironment(const QString pathsFileName, QString *errorMsg)
+{
+  QProcessEnvironment environment = StringHandler::simulationProcessEnvironment();
+
+  // Parse the fileName.bat file to get the necessary paths.
+  // Return errorMsg if fails to parse the file as expected.
+  QFile batFile(pathsFileName);
+  batFile.open(QIODevice::ReadOnly | QIODevice::Text);
+
+  QString line;
+  // first line is supposed to be '@echo off'
+  line = batFile.readLine();
+  // Second line is where the PATH is set. We want that.
+  line = batFile.readLine();
+
+  if (!line.toLower().startsWith("set path=")) {
+    *errorMsg = "Failed to read the neccesary PATH values from '" + pathsFileName + "'\n"
+                + "If simulation fails please check that you have the bat file and it is formatted correctly\n";
+  } else {
+    // Strip the 'set PATH='
+    line.remove(0, 9);
+    environment.insert("PATH", line + ";" + environment.value("PATH"));
+  }
+  batFile.close();
+
+  return environment;
+}
 #endif
 
 StringHandler::SimulationMessageType StringHandler::getSimulationMessageType(QString type)
