@@ -624,7 +624,9 @@ QSettings* Utilities::getApplicationSettings()
   if (!init) {
     init = 1;
     pSettings = new QSettings(QSettings::IniFormat, QSettings::UserScope, Helper::organization, Helper::application);
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     pSettings->setIniCodec(Helper::utf8.toUtf8().constData());
+#endif
   }
   return pSettings;
 }
@@ -1045,15 +1047,8 @@ QString Utilities::getGDBPath()
 {
 #if defined(_WIN32)
   const char *OMDEV = getenv("OMDEV");
-  const char *MSYSTEM_PREFIX = getenv("MSYSTEM_PREFIX");
   const char* msysEnv = System_openModelicaPlatform(); /* "ucrt64" or "mingw64" */
 
-  // MSYSTEM_PREFIX is set: <MSYSTEM_PREFIX>/bin/gdb.exe
-  if (!QString(MSYSTEM_PREFIX).isEmpty()) {
-    QString qMSYSTEM_PREFIX = QString(MSYSTEM_PREFIX).replace("\\", "/");
-    return QString(qMSYSTEM_PREFIX) + QString("/bin/gdb.exe");
-  }
-
   // OMDEV is set: <OMDEV>/tools/msys/<CONFIG_OPENMODELICA_SPEC_PLATFORM>/bin/gdb.exe
   if (!QString(OMDEV).isEmpty()) {
     QString qOMDEV = QString(OMDEV).replace("\\", "/");
@@ -1061,7 +1056,7 @@ QString Utilities::getGDBPath()
   }
 
   // Default: <OPENMODELICAHOME>/tools/msys/<CONFIG_OPENMODELICA_SPEC_PLATFORM>/bin/gdb.exe
-  return QString(Helper::OpenModelicaHome) + QString("/tools/msys/") + QString(msysEnv) + QString("bin/gdb.exe");
+  return QString(Helper::OpenModelicaHome) + QString("/tools/msys/") + QString(msysEnv) + QString("/bin/gdb.exe");
 #else
   return "gdb";
 #endif
@@ -1298,12 +1293,17 @@ void Utilities::addDefaultDisplayUnit(const QString &unit, QStringList &displayU
   /* Issue #8758
    * Whenever unit = "K", we also add "degC" even if it is not defined as displayUnits.
    */
+  /* Issue #12340
+   * Whenever unit = "m/s", we also add "km/h" even if it is not defined as displayUnits.
+   */
   if (unit.compare(QStringLiteral("rad/s")) == 0) {
     displayUnit << "rpm";
   } else if (unit.compare(QStringLiteral("J")) == 0) {
     displayUnit << "Wh";
   } else if (unit.compare(QStringLiteral("K")) == 0) {
     displayUnit << "degC";
+  } else if (unit.compare(QStringLiteral("m/s")) == 0) {
+    displayUnit << "km/h";
   }
 }
 
