@@ -264,6 +264,11 @@ inline QDataStream& operator>>(QDataStream& in, RecentFile& recentFile)
   return in;
 }
 
+inline bool operator==(const RecentFile& lhs, const RecentFile& rhs)
+{
+  return lhs.fileName == rhs.fileName;
+}
+
 //! @struct FindTextOM
 /*! \brief It contains the recently searched text from find/replace dialog .
  * We must register this struct as a meta type since we need to use it as a QVariant.
@@ -292,6 +297,11 @@ inline QDataStream& operator>>(QDataStream& in, FindTextOM& findText)
   return in;
 }
 
+inline bool operator==(const FindTextOM& lhs, const FindTextOM& rhs)
+{
+  return lhs.text == rhs.text;
+}
+
 //! @struct DebuggerConfiguration
 /*! \brief It contains the debugger configuration settings  from debugger configuration dialog .
  * We must register this struct as a meta type since we need to use it as a QVariant.
@@ -332,6 +342,11 @@ inline QDataStream& operator>>(QDataStream& in, DebuggerConfiguration& configura
   return in;
 }
 
+inline bool operator==(const DebuggerConfiguration& lhs, const DebuggerConfiguration& rhs)
+{
+  return lhs.name == rhs.name;
+}
+
 /*!
  * \class MessageHandler
  * \brief Defines the appropriate error message of the parsed XML validated againast the XML Schema.\n
