@@ -36,6 +36,8 @@
 #include "qwt_painter.h"
 #endif
 #include "qwt_symbol.h"
+#include "qwt_scale_map.h"
+#include "qwt_point_polar.h"
 
 using namespace OMPlot;
 
@@ -249,6 +251,29 @@ void PlotCurve::toggleVisibility(bool visibility)
   setVisible(visibility);
 }
 
+/*!
+ * \brief PlotCurve::resetPrefixUnit
+ * Resets the unit prefix.
+ */
+void PlotCurve::resetPrefixUnit()
+{
+  if (!mXUnitPrefix.isEmpty()) {
+    for (int i = 0 ; i < mXAxisVector.size() ; i++) {
+      updateXAxisValue(i, mXAxisVector.at(i) * qPow(10, mXExponent));
+    }
+  }
+  mXUnitPrefix = "";
+  mXExponent = 0;
+
+  if (!mYUnitPrefix.isEmpty()) {
+    for (int i = 0 ; i < mYAxisVector.size() ; i++) {
+      updateYAxisValue(i, mYAxisVector.at(i) * qPow(10, mYExponent));
+    }
+  }
+  mYUnitPrefix = "";
+  mYExponent = 0;
+}
+
 /*!
  * \brief PlotCurve::plotData
  * Plot the curve data.
@@ -290,7 +315,7 @@ void PlotCurve::plotData(bool toggleSign)
         // update if unit prefix is not empty.
         if (!mXUnitPrefix.isEmpty()) {
           for (int i = 0 ; i < mXAxisVector.size() ; i++) {
-            mXAxisVector.replace(i, mXAxisVector.at(i) / qPow(10, mXExponent));
+            updateXAxisValue(i, mXAxisVector.at(i) / qPow(10, mXExponent));
           }
         }
       }
@@ -306,21 +331,7 @@ void PlotCurve::plotData(bool toggleSign)
       }
     } else {
       // revert the values when there is no perfixUnits.
-      if (!mXUnitPrefix.isEmpty()) {
-        for (int i = 0 ; i < mXAxisVector.size() ; i++) {
-          updateXAxisValue(i, mXAxisVector.at(i) * qPow(10, mXExponent));
-        }
-      }
-      mXUnitPrefix = "";
-      mXExponent = 0;
-
-      if (!mYUnitPrefix.isEmpty()) {
-        for (int i = 0 ; i < mYAxisVector.size() ; i++) {
-          updateYAxisValue(i, mYAxisVector.at(i) * qPow(10, mYExponent));
-        }
-      }
-      mYUnitPrefix = "";
-      mYExponent = 0;
+      resetPrefixUnit();
     }
   }
   setSamples(mXAxisVector, mYAxisVector);
